import React from 'react';
import { Bot, Workflow, ArrowRight } from 'lucide-react';
import { Link } from 'react-router-dom';

const Services: React.FC = () => {
  return (
    <section 
      id="services" 
      className="relative py-20 overflow-hidden bg-gradient-to-br from-gray-900 via-gray-800 to-gray-900"
      aria-labelledby="services-heading"
    >
      <div className="absolute inset-0 bg-[radial-gradient(circle_at_30%_50%,rgba(59,130,246,0.1),transparent_50%)]"></div>
      <div className="container mx-auto px-4 md:px-6 lg:px-8 relative">
        <h2 id="services-heading" className="text-3xl md:text-4xl font-bold text-center text-white mb-16">
          What We Do
        </h2>
        
        <div className="grid lg:grid-cols-2 gap-8 max-w-7xl mx-auto">
          <div className="relative group hover:scale-[1.02] transition-all duration-500">
            <Link to="/ai-automation" className="block" aria-label="Learn more about AI Automation">
            <div className="absolute inset-0 bg-gradient-to-r from-blue-500/50 to-purple-500/50 rounded-3xl blur-xl group-hover:blur-2xl group-hover:scale-110 transition-all duration-500"></div>
            <div className="relative bg-gray-800/90 backdrop-blur-sm rounded-3xl p-8 border border-blue-500/30 shadow-[0_0_30px_rgba(59,130,246,0.3)] transition-all duration-500 hover:shadow-[0_0_50px_rgba(59,130,246,0.5)] overflow-hidden">
              <div className="absolute inset-0 bg-gradient-to-r from-blue-600/10 to-purple-600/10 opacity-0 group-hover:opacity-100 transition-all duration-500"></div>
              <div className="relative">
                <div className="bg-gradient-to-br from-blue-500 to-indigo-600 w-20 h-20 rounded-2xl flex items-center justify-center mb-8 shadow-xl group-hover:scale-110 group-hover:rotate-6 transition-all duration-500">
                  <Workflow className="h-10 w-10 text-white" />
                </div>
                
                <h3 className="text-3xl font-bold bg-gradient-to-r from-blue-400 to-indigo-400 bg-clip-text text-transparent mb-4">
                  AI Automation
                </h3>
                <p className="text-gray-200 leading-relaxed mb-8">
                  We identify inefficiencies in your workflow and build custom AI solutions to automate them, streamlining your operations and boosting productivity.
                </p>
                <div className="inline-flex items-center px-6 py-3 bg-gradient-to-r from-blue-500 to-indigo-500 text-white font-semibold rounded-full group/link cursor-pointer hover:shadow-[0_0_20px_rgba(59,130,246,0.5)] transition-all duration-300">
                  <span className="mr-2">Learn more</span>
                  <ArrowRight className="h-5 w-5 transform group-hover/link:translate-x-2 transition-transform duration-300" />
                </div>
              </div>
            </div>
            </Link>
          </div>
          
          <div className="relative group hover:scale-[1.02] transition-all duration-500">
            <Link to="/smart-chatbots" className="block" aria-label="Learn more about Smart Chatbots">
            <div className="absolute inset-0 bg-gradient-to-r from-purple-500/50 to-pink-500/50 rounded-3xl blur-xl group-hover:blur-2xl group-hover:scale-110 transition-all duration-500"></div>
            <div className="relative bg-gray-800/90 backdrop-blur-sm rounded-3xl p-8 border border-purple-500/30 shadow-[0_0_30px_rgba(168,85,247,0.3)] transition-all duration-500 hover:shadow-[0_0_50px_rgba(168,85,247,0.5)] overflow-hidden">
              <div className="absolute inset-0 bg-gradient-to-r from-purple-600/10 to-pink-600/10 opacity-0 group-hover:opacity-100 transition-all duration-500"></div>
              <div className="relative">
                <div className="bg-gradient-to-br from-purple-500 to-pink-600 w-20 h-20 rounded-2xl flex items-center justify-center mb-8 shadow-xl group-hover:scale-110 group-hover:rotate-6 transition-all duration-500">
                  <Bot className="h-10 w-10 text-white" />
                </div>
                
                <h3 className="text-3xl font-bold bg-gradient-to-r from-purple-400 to-pink-400 bg-clip-text text-transparent mb-4">
                  Smart Chatbots
                </h3>
                <p className="text-gray-300 leading-relaxed mb-8">
                  Our AI-powered chatbots can book appointments, qualify leads, and answer detailed questions about your business in real-time, providing 24/7 customer support.
                </p>
                <div className="inline-flex items-center px-6 py-3 bg-gradient-to-r from-purple-500 to-pink-500 text-white font-semibold rounded-full group/link cursor-pointer hover:shadow-[0_0_20px_rgba(168,85,247,0.5)] transition-all duration-300">
                  <span className="mr-2">Learn more</span>
                  <ArrowRight className="h-5 w-5 transform group-hover/link:translate-x-2 transition-transform duration-300" />
                </div>
              </div>
            </div>
            </Link>
          </div>
        </div>
      </div>
    </section>
  );
};

export default Services;